Documentation
¶
Overview ¶
Package v1 contains API Schema definitions for the cert-orchestrator v1 API group +kubebuilder:object:generate=true +groupName=cert-orchestrator.certplus.appviewx
Index ¶
- Constants
- Variables
- type AppViewXCASetting
- type CACASetting
- type CAConnectorInfo
- type CASetting
- type CASettingCluster
- type CASettingClusterList
- type CASettingClusterSpec
- type CASettingClusterStatus
- type CASettingConfig
- type CASettingList
- type CASettingSpec
- type CASettingStatus
- type Cert
- type CertList
- type CertPolicy
- type CertPolicyList
- type CertPolicySpec
- type CertPolicyStatus
- type CertReq
- type CertReqList
- type CertReqSpec
- type CertReqStatus
- type CertSpec
- type CertStatus
- type CertificateCondition
- type CertificateConditionType
- type CertificateGroup
- type CertificateKeystores
- type CertificatePrivateKey
- type CertificateSecretTemplate
- type Duration
- type ESTSetting
- type IssuerCondition
- type IssuerConditionType
- type JKS
- type KeyUsage
- type NamespacedName
- type ObjectReference
- type PKCS12
- type PrivateKeyAlgorithm
- type PrivateKeyEncoding
- type PrivateKeyRotationPolicy
- type RenewalJob
- type RenewalJobList
- type RenewalJobSpec
- type RenewalJobStatus
- type SelfSignedCASetting
- type VaultAppRole
- type VaultAuth
- type VaultCASetting
- type VaultConfiguration
- type VaultKubernetesAuth
- type X509Subject
Constants ¶
const ( CertificateConditionReady CertificateConditionType = "Ready" CertificateConditionIssuing CertificateConditionType = "Issuing" CertificateConditionIssued string = "Issued" )
const ( CertificateRequestReasonPending = "Pending" CertificateRequestReasonFailed = "Failed" CertificateRequestReasonIssued = "Issued" CertificateRequestReasonDenied = "Denied" )
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "cert-orchestrator.certplus.appviewx", Version: "v1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type AppViewXCASetting ¶
type AppViewXCASetting struct {
Host string `json:"host"`
Port int `json:"port"`
IsHttps bool `json:"isHttps"`
CAConnectorInfo CAConnectorInfo `json:"caConnectorInfo"`
Category string `json:"category"`
CertificateGroup CertificateGroup `json:"certificateGroup"`
// +optional
Secret *NamespacedName `json:"secret"`
// +optional
Vault *VaultConfiguration `json:"vault"`
// +optional
IsSync bool `json:"isSync"`
}
TODO:
func (*AppViewXCASetting) DeepCopy ¶
func (in *AppViewXCASetting) DeepCopy() *AppViewXCASetting
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AppViewXCASetting.
func (*AppViewXCASetting) DeepCopyInto ¶
func (in *AppViewXCASetting) DeepCopyInto(out *AppViewXCASetting)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CACASetting ¶
type CACASetting struct {
SecretName string `json:"secretName"`
// +optional
CRLDistributionPoints []string `json:"crlDistributionPoints,omitempty"`
// +optional
OCSPServers []string `json:"ocspServers,omitempty"`
}
func (*CACASetting) DeepCopy ¶
func (in *CACASetting) DeepCopy() *CACASetting
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CACASetting.
func (*CACASetting) DeepCopyInto ¶
func (in *CACASetting) DeepCopyInto(out *CACASetting)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CAConnectorInfo ¶
type CAConnectorInfo struct {
CASettingName string `json:"caSettingName"`
CertificateAuthority string `json:"certificateAuthority"`
// +optional
CertificateType string `json:"certificateType"`
// +optional
ValidityUnit *string `json:"validityUnit"`
// +optional
ValidityUnitValue *int `json:"validityUnitValue"`
//Need to convert to map[string]interface{}
// +optional
VendorSpecificDetails *string `json:"vendorSpecificDetails"`
//+optional
CertificateProfileName *string `json:"certificateProfileName"`
//+optional
IssuerLocation *string `json:"issuerLocation"`
//+optional
IssuerName *string `json:"issuerName"`
//+optional
Name *string `json:"name"`
}
func (*CAConnectorInfo) DeepCopy ¶
func (in *CAConnectorInfo) DeepCopy() *CAConnectorInfo
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CAConnectorInfo.
func (*CAConnectorInfo) DeepCopyInto ¶
func (in *CAConnectorInfo) DeepCopyInto(out *CAConnectorInfo)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CASetting ¶
type CASetting struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec CASettingSpec `json:"spec,omitempty"`
Status CASettingStatus `json:"status,omitempty"`
}
CASetting is the Schema for the casettings API
func (*CASetting) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CASetting.
func (*CASetting) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CASetting) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CASettingCluster ¶
type CASettingCluster struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec CASettingClusterSpec `json:"spec,omitempty"`
Status CASettingClusterStatus `json:"status,omitempty"`
}
CASettingCluster is the Schema for the casettingclusters API
func (*CASettingCluster) DeepCopy ¶
func (in *CASettingCluster) DeepCopy() *CASettingCluster
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CASettingCluster.
func (*CASettingCluster) DeepCopyInto ¶
func (in *CASettingCluster) DeepCopyInto(out *CASettingCluster)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CASettingCluster) DeepCopyObject ¶
func (in *CASettingCluster) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CASettingClusterList ¶
type CASettingClusterList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []CASettingCluster `json:"items"`
}
CASettingClusterList contains a list of CASettingCluster
func (*CASettingClusterList) DeepCopy ¶
func (in *CASettingClusterList) DeepCopy() *CASettingClusterList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CASettingClusterList.
func (*CASettingClusterList) DeepCopyInto ¶
func (in *CASettingClusterList) DeepCopyInto(out *CASettingClusterList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CASettingClusterList) DeepCopyObject ¶
func (in *CASettingClusterList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CASettingClusterSpec ¶
type CASettingClusterSpec struct {
CASettingConfig `json:",inline"`
}
CASettingClusterSpec defines the desired state of CASettingCluster
func (*CASettingClusterSpec) DeepCopy ¶
func (in *CASettingClusterSpec) DeepCopy() *CASettingClusterSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CASettingClusterSpec.
func (*CASettingClusterSpec) DeepCopyInto ¶
func (in *CASettingClusterSpec) DeepCopyInto(out *CASettingClusterSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CASettingClusterStatus ¶
type CASettingClusterStatus struct {
}
CASettingClusterStatus defines the observed state of CASettingCluster
func (*CASettingClusterStatus) DeepCopy ¶
func (in *CASettingClusterStatus) DeepCopy() *CASettingClusterStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CASettingClusterStatus.
func (*CASettingClusterStatus) DeepCopyInto ¶
func (in *CASettingClusterStatus) DeepCopyInto(out *CASettingClusterStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CASettingConfig ¶
type CASettingConfig struct {
// +optional
CA *CACASetting `json:"ca"`
// +optional
Vault *VaultCASetting `json:"vault,omitempty"`
// +optional
SelfSigned *SelfSignedCASetting `json:"selfSigned,omitempty"`
// +optional
AppViewX *AppViewXCASetting `json:"appviewx,omitempty"`
// +optional
EST *ESTSetting `json:"est,omitempty"`
}
func (*CASettingConfig) DeepCopy ¶
func (in *CASettingConfig) DeepCopy() *CASettingConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CASettingConfig.
func (*CASettingConfig) DeepCopyInto ¶
func (in *CASettingConfig) DeepCopyInto(out *CASettingConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CASettingList ¶
type CASettingList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []CASetting `json:"items"`
}
CASettingList contains a list of CASetting
func (*CASettingList) DeepCopy ¶
func (in *CASettingList) DeepCopy() *CASettingList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CASettingList.
func (*CASettingList) DeepCopyInto ¶
func (in *CASettingList) DeepCopyInto(out *CASettingList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CASettingList) DeepCopyObject ¶
func (in *CASettingList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CASettingSpec ¶
type CASettingSpec struct {
// Foo is an example field of CASetting. Edit CASetting_types.go to remove/update
// Foo string `json:"foo,omitempty"`
CASettingConfig `json:",inline"`
}
CASettingSpec defines the desired state of CASetting
func (*CASettingSpec) DeepCopy ¶
func (in *CASettingSpec) DeepCopy() *CASettingSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CASettingSpec.
func (*CASettingSpec) DeepCopyInto ¶
func (in *CASettingSpec) DeepCopyInto(out *CASettingSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CASettingStatus ¶
type CASettingStatus struct {
// +optional
Conditions []IssuerCondition `json:"conditions,omitempty"`
}
CASettingStatus defines the observed state of CASetting
func (*CASettingStatus) DeepCopy ¶
func (in *CASettingStatus) DeepCopy() *CASettingStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CASettingStatus.
func (*CASettingStatus) DeepCopyInto ¶
func (in *CASettingStatus) DeepCopyInto(out *CASettingStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Cert ¶
type Cert struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec CertSpec `json:"spec,omitempty"`
Status CertStatus `json:"status,omitempty"`
}
Cert is the Schema for the certs API
func (*Cert) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Cert.
func (*Cert) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Cert) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CertList ¶
type CertList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Cert `json:"items"`
}
CertList contains a list of Cert
func (*CertList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertList.
func (*CertList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CertList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CertPolicy ¶
type CertPolicy struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec CertPolicySpec `json:"spec,omitempty"`
Status CertPolicyStatus `json:"status,omitempty"`
}
CertPolicy is the Schema for the certpolicies API
func (*CertPolicy) DeepCopy ¶
func (in *CertPolicy) DeepCopy() *CertPolicy
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertPolicy.
func (*CertPolicy) DeepCopyInto ¶
func (in *CertPolicy) DeepCopyInto(out *CertPolicy)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CertPolicy) DeepCopyObject ¶
func (in *CertPolicy) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CertPolicyList ¶
type CertPolicyList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []CertPolicy `json:"items"`
}
CertPolicyList contains a list of CertPolicy
func (*CertPolicyList) DeepCopy ¶
func (in *CertPolicyList) DeepCopy() *CertPolicyList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertPolicyList.
func (*CertPolicyList) DeepCopyInto ¶
func (in *CertPolicyList) DeepCopyInto(out *CertPolicyList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CertPolicyList) DeepCopyObject ¶
func (in *CertPolicyList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CertPolicySpec ¶
type CertPolicySpec struct {
// Foo is an example field of CertPolicy. Edit certpolicy_types.go to remove/update
Foo string `json:"foo,omitempty"`
}
CertPolicySpec defines the desired state of CertPolicy
func (*CertPolicySpec) DeepCopy ¶
func (in *CertPolicySpec) DeepCopy() *CertPolicySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertPolicySpec.
func (*CertPolicySpec) DeepCopyInto ¶
func (in *CertPolicySpec) DeepCopyInto(out *CertPolicySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CertPolicyStatus ¶
type CertPolicyStatus struct {
}
CertPolicyStatus defines the observed state of CertPolicy
func (*CertPolicyStatus) DeepCopy ¶
func (in *CertPolicyStatus) DeepCopy() *CertPolicyStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertPolicyStatus.
func (*CertPolicyStatus) DeepCopyInto ¶
func (in *CertPolicyStatus) DeepCopyInto(out *CertPolicyStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CertReq ¶
type CertReq struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec CertReqSpec `json:"spec,omitempty"`
Status CertReqStatus `json:"status,omitempty"`
}
CertReq is the Schema for the certreqs API
func (*CertReq) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertReq.
func (*CertReq) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CertReq) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CertReqList ¶
type CertReqList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []CertReq `json:"items"`
}
CertReqList contains a list of CertReq
func (*CertReqList) DeepCopy ¶
func (in *CertReqList) DeepCopy() *CertReqList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertReqList.
func (*CertReqList) DeepCopyInto ¶
func (in *CertReqList) DeepCopyInto(out *CertReqList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CertReqList) DeepCopyObject ¶
func (in *CertReqList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CertReqSpec ¶
type CertReqSpec struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Duration *metav1.Duration `json:"duration,omitempty"`
CASettingRef ObjectReference `json:"caSettingRef"`
Request []byte `json:"request,omitempty"`
IsCA bool `json:"isCA,omitempty"`
Usages []KeyUsage `json:"usages,omitempty"`
}
CertReqSpec defines the desired state of CertReq
func (*CertReqSpec) DeepCopy ¶
func (in *CertReqSpec) DeepCopy() *CertReqSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertReqSpec.
func (*CertReqSpec) DeepCopyInto ¶
func (in *CertReqSpec) DeepCopyInto(out *CertReqSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CertReqStatus ¶
type CertReqStatus struct {
Certificate string `json:"certificate,omitempty"`
Status string `json:"status,omitempty"`
TLS_CRT []byte `json:"tls_crt,omitempty"`
CA_CRT []byte `json:"ca_crt,omitempty"`
PickupID string `json:"pickup_id,omitempty"`
}
CertReqStatus defines the observed state of CertReq
func (*CertReqStatus) DeepCopy ¶
func (in *CertReqStatus) DeepCopy() *CertReqStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertReqStatus.
func (*CertReqStatus) DeepCopyInto ¶
func (in *CertReqStatus) DeepCopyInto(out *CertReqStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CertSpec ¶
type CertSpec struct {
//CommonName valid common name for the Certificate
CommonName string `json:"commonName,omitempty"`
Subject *X509Subject `json:"subject,omitempty"`
Duration *metav1.Duration `json:"duration,omitempty"`
RenewBefore *metav1.Duration `json:"renewBefore,omitempty"`
DNSNames []string `json:"dnsNames,omitempty"`
IPAddresses []string `json:"ipAddresses,omitempty"`
URIs []string `json:"uris,omitempty"`
EmailAddresses []string `json:"emailAddresses,omitempty"`
SecretName string `json:"secretName"`
SecretTemplate *CertificateSecretTemplate `json:"secretTemplate,omitempty"`
KeyStores *CertificateKeystores `json:"keystores,omitempty"`
CASettingRef ObjectReference `json:"caSettingRef"`
IsCA bool `json:"isCA,omitempty"`
Usages []KeyUsage `json:"usages,omitempty"`
PrivateKey *CertificatePrivateKey `json:"privateKey,omitempty"`
EncodeUsagesInRequest *bool `json:"encodeUsagesInRequest,omitempty"`
RevisionHistoryLimit *int32 `json:"revisionHistoryLimit,omitempty"`
CSR string `json:"csr,omitempty"`
}
CertSpec expected state of the certificate. Any one CommonName or DNSName or URISAN is mandatory
func (*CertSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertSpec.
func (*CertSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CertStatus ¶
type CertStatus struct {
Conditions []CertificateCondition `json:"conditions,omitempty"`
LastFailureTime *metav1.Time `json:"lastFailureTime,omitempty"`
NotBefore *metav1.Time `json:"notBefore,omitempty"`
NotAfter *metav1.Time `json:"notAfter,omitempty"`
RenewalTime *metav1.Time `json:"renewalTime,omitempty"`
Revision *int `json:"revision,omitempty"`
NextPrivateKeySecretName *string `json:"nextPrivateKeySecretName,omitempty"`
CertificateRequestName *string `json:"certificaterequestname,omitempty"`
Certificate []byte `json:"certificate,omitempty"`
ReadyTime *metav1.Time `json:"readyTime,omitempty"`
}
CertStatus observed state of certificate
func (*CertStatus) DeepCopy ¶
func (in *CertStatus) DeepCopy() *CertStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertStatus.
func (*CertStatus) DeepCopyInto ¶
func (in *CertStatus) DeepCopyInto(out *CertStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CertificateCondition ¶
type CertificateCondition struct {
//Type allowed values Ready,Issuing
Type CertificateConditionType `json:"type"`
Status metaco.ConditionStatus `json:"status"`
LastTransitionTime *metav1.Time `json:"lastTransitionTime,omitempty"`
Reason string `json:"reason,omitempty"`
Message string `json:"message,omitempty"`
ObservedGeneration int64 `json:"observedGeneration,omitempty"`
}
CertificateCondition provides the condition information
func (*CertificateCondition) DeepCopy ¶
func (in *CertificateCondition) DeepCopy() *CertificateCondition
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertificateCondition.
func (*CertificateCondition) DeepCopyInto ¶
func (in *CertificateCondition) DeepCopyInto(out *CertificateCondition)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CertificateConditionType ¶
type CertificateConditionType string
type CertificateGroup ¶
type CertificateGroup struct {
Name string `json:"name"`
}
func (*CertificateGroup) DeepCopy ¶
func (in *CertificateGroup) DeepCopy() *CertificateGroup
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertificateGroup.
func (*CertificateGroup) DeepCopyInto ¶
func (in *CertificateGroup) DeepCopyInto(out *CertificateGroup)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CertificateKeystores ¶
type CertificateKeystores struct {
// +optional
JKS *JKS `json:"jks,omitempty"`
// +optional
PKCS12 *PKCS12 `json:"pkcs12,omitempty"`
}
func (*CertificateKeystores) DeepCopy ¶
func (in *CertificateKeystores) DeepCopy() *CertificateKeystores
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertificateKeystores.
func (*CertificateKeystores) DeepCopyInto ¶
func (in *CertificateKeystores) DeepCopyInto(out *CertificateKeystores)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CertificatePrivateKey ¶
type CertificatePrivateKey struct {
//Policy how the Private Keys should be regenerated when a re-issuance is being processed
//'Never' Generated only iff doesn't exist
//'Always' will be generated newly
Policy PrivateKeyRotationPolicy `json:"rotationPolicy,omitempty"`
//Encoding allowed formats are PKCS1 PKCS8
//defaults to PKCS1
Encoding PrivateKeyEncoding `json:"encoding,omitempty"`
//Algorithm allowed values are RSA, ECDSA
// for RSA it is 2048, for ECDSA it is 256 are the default key sizes
Algorithm PrivateKeyAlgorithm `json:"algorithm,omitempty"`
//Size bit size of the key
// for RSA it is 2048, 4096, 8192 , for ECDSA it is 256,384,521 are the supported values
Size int `json:"size,omitempty"`
}
CertificatePrivateKey configuration controls the rotation of PrivateKeys
func (*CertificatePrivateKey) DeepCopy ¶
func (in *CertificatePrivateKey) DeepCopy() *CertificatePrivateKey
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertificatePrivateKey.
func (*CertificatePrivateKey) DeepCopyInto ¶
func (in *CertificatePrivateKey) DeepCopyInto(out *CertificatePrivateKey)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CertificateSecretTemplate ¶
type CertificateSecretTemplate struct {
// +optional
Annotations map[string]string `json:"annotations,omitempty"`
// +optional
Labels map[string]string `json:"labels,omitempty"`
}
func (*CertificateSecretTemplate) DeepCopy ¶
func (in *CertificateSecretTemplate) DeepCopy() *CertificateSecretTemplate
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CertificateSecretTemplate.
func (*CertificateSecretTemplate) DeepCopyInto ¶
func (in *CertificateSecretTemplate) DeepCopyInto(out *CertificateSecretTemplate)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Duration ¶
type Duration struct {
time.Duration `protobuf:"varint,1,opt,name=duration,casttype=time.Duration"`
}
func (*Duration) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Duration.
func (*Duration) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ESTSetting ¶
type ESTSetting struct {
HostName string `json:"host"`
Port int `json:"port"`
// +optional
PathSegment string `json:"pathSegment"`
AuthenticationSecret *NamespacedName `json:"authenticationSecret"`
}
func (*ESTSetting) DeepCopy ¶
func (in *ESTSetting) DeepCopy() *ESTSetting
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ESTSetting.
func (*ESTSetting) DeepCopyInto ¶
func (in *ESTSetting) DeepCopyInto(out *ESTSetting)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IssuerCondition ¶
type IssuerCondition struct {
Type IssuerConditionType `json:"type"`
Status meta.ConditionStatus `json:"status"`
// +optional
LastTransitionTime *metav1.Time `json:"lastTranstionTime,omitempty"`
// +optional
Reason string `json:"reason,omitempty"`
// +optional
Message string `json:"message,omitempty"`
// +optional
ObservedGeneration int64 `json:"observedGeneration,omitempty"`
}
func (*IssuerCondition) DeepCopy ¶
func (in *IssuerCondition) DeepCopy() *IssuerCondition
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IssuerCondition.
func (*IssuerCondition) DeepCopyInto ¶
func (in *IssuerCondition) DeepCopyInto(out *IssuerCondition)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IssuerConditionType ¶
type IssuerConditionType string
type JKS ¶
type JKS struct {
Create bool `json:"create"`
Password meta.SecretKeySelector `json:"password"`
}
func (*JKS) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new JKS.
func (*JKS) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type KeyUsage ¶
type KeyUsage string
+kubebuilder:validation:Enum="signing";"digital signature";"content commitment";"key encipherment";"key agreement";"data encipherment";"cert sign";"crl sign";"encipher only";"decipher only";"any";"server auth";"client auth";"code signing";"email protection";"s/mime";"ipsec end system";"ipsec tunnel";"ipsec user";"timestamping";"ocsp signing";"microsoft sgc";"netscape sgc"
const ( UsageSigning KeyUsage = "signing" UsageDigitalSignature KeyUsage = "digital signature" UsageContentCommitment KeyUsage = "content commitment" UsageKeyEncipherment KeyUsage = "key encipherment" UsageKeyAgreement KeyUsage = "key agreement" UsageDataEncipherment KeyUsage = "data encipherment" UsageCertSign KeyUsage = "cert sign" UsageCRLSign KeyUsage = "crl sign" UsageEncipherOnly KeyUsage = "encipher only" UsageDecipherOnly KeyUsage = "decipher only" UsageAny KeyUsage = "any" UsageServerAuth KeyUsage = "server auth" UsageClientAuth KeyUsage = "client auth" UsageCodeSigning KeyUsage = "code signing" UsageEmailProtection KeyUsage = "email protection" UsageSMIME KeyUsage = "s/mime" UsageIPsecEndSystem KeyUsage = "ipsec end system" UsageIPsecTunnel KeyUsage = "ipsec tunnel" UsageIPsecUser KeyUsage = "ipsec user" UsageTimestamping KeyUsage = "timestamping" UsageOCSPSigning KeyUsage = "ocsp signing" UsageMicrosoftSGC KeyUsage = "microsoft sgc" UsageNetscapeSGC KeyUsage = "netscape sgc" )
type NamespacedName ¶
func (*NamespacedName) DeepCopy ¶
func (in *NamespacedName) DeepCopy() *NamespacedName
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NamespacedName.
func (*NamespacedName) DeepCopyInto ¶
func (in *NamespacedName) DeepCopyInto(out *NamespacedName)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ObjectReference ¶
type ObjectReference struct {
// Name of the resource being referred to.
Name string `json:"name"`
// Kind of the resource being referred to.
// +optional
Kind string `json:"kind,omitempty"`
// Group of the resource being referred to.
// +optional
Group string `json:"group,omitempty"`
}
ObjectReference is a reference to an object with a given name, kind and group.
func (*ObjectReference) DeepCopy ¶
func (in *ObjectReference) DeepCopy() *ObjectReference
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ObjectReference.
func (*ObjectReference) DeepCopyInto ¶
func (in *ObjectReference) DeepCopyInto(out *ObjectReference)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PKCS12 ¶
type PKCS12 struct {
Create bool `json:"create"`
Password meta.SecretKeySelector `json:"password"`
}
func (*PKCS12) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PKCS12.
func (*PKCS12) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PrivateKeyAlgorithm ¶
type PrivateKeyAlgorithm string
var ( RSA PrivateKeyAlgorithm = "RSA" ECDSA PrivateKeyAlgorithm = "ECDSA" )
type PrivateKeyEncoding ¶
type PrivateKeyEncoding string
var ( PKCS1 PrivateKeyEncoding = "PKCS1" PKCS8 PrivateKeyEncoding = "PKCS8" )
type PrivateKeyRotationPolicy ¶
type PrivateKeyRotationPolicy string
var ( RotationPolicyNever PrivateKeyRotationPolicy = "never" RotationPolicyAlways PrivateKeyRotationPolicy = "always" )
type RenewalJob ¶
type RenewalJob struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec RenewalJobSpec `json:"spec,omitempty"`
Status RenewalJobStatus `json:"status,omitempty"`
}
RenewalJob is the Schema for the renewaljobs API
func (*RenewalJob) DeepCopy ¶
func (in *RenewalJob) DeepCopy() *RenewalJob
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RenewalJob.
func (*RenewalJob) DeepCopyInto ¶
func (in *RenewalJob) DeepCopyInto(out *RenewalJob)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*RenewalJob) DeepCopyObject ¶
func (in *RenewalJob) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type RenewalJobList ¶
type RenewalJobList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []RenewalJob `json:"items"`
}
RenewalJobList contains a list of RenewalJob
func (*RenewalJobList) DeepCopy ¶
func (in *RenewalJobList) DeepCopy() *RenewalJobList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RenewalJobList.
func (*RenewalJobList) DeepCopyInto ¶
func (in *RenewalJobList) DeepCopyInto(out *RenewalJobList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*RenewalJobList) DeepCopyObject ¶
func (in *RenewalJobList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type RenewalJobSpec ¶
type RenewalJobSpec struct {
// Foo is an example field of RenewalJob. Edit RenewalJob_types.go to remove/update
Foo string `json:"foo,omitempty"`
}
RenewalJobSpec defines the desired state of RenewalJob
func (*RenewalJobSpec) DeepCopy ¶
func (in *RenewalJobSpec) DeepCopy() *RenewalJobSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RenewalJobSpec.
func (*RenewalJobSpec) DeepCopyInto ¶
func (in *RenewalJobSpec) DeepCopyInto(out *RenewalJobSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RenewalJobStatus ¶
type RenewalJobStatus struct {
}
RenewalJobStatus defines the observed state of RenewalJob
func (*RenewalJobStatus) DeepCopy ¶
func (in *RenewalJobStatus) DeepCopy() *RenewalJobStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RenewalJobStatus.
func (*RenewalJobStatus) DeepCopyInto ¶
func (in *RenewalJobStatus) DeepCopyInto(out *RenewalJobStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SelfSignedCASetting ¶
type SelfSignedCASetting struct {
// +optional
CRLDistributionPoints []string `json:"crlDistributionPoints,omitempty"`
}
func (*SelfSignedCASetting) DeepCopy ¶
func (in *SelfSignedCASetting) DeepCopy() *SelfSignedCASetting
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SelfSignedCASetting.
func (*SelfSignedCASetting) DeepCopyInto ¶
func (in *SelfSignedCASetting) DeepCopyInto(out *SelfSignedCASetting)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VaultAppRole ¶
type VaultAppRole struct {
Path string `json:"path"`
RoleId string `json:"roleId"`
SecretRef meta.SecretKeySelector `json:"secretRef"`
}
func (*VaultAppRole) DeepCopy ¶
func (in *VaultAppRole) DeepCopy() *VaultAppRole
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VaultAppRole.
func (*VaultAppRole) DeepCopyInto ¶
func (in *VaultAppRole) DeepCopyInto(out *VaultAppRole)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VaultAuth ¶
type VaultAuth struct {
// +optional
TokenSecretRef *meta.SecretKeySelector `json:"tokenSecretRef,omitempty"`
// +optional
AppRole *VaultAppRole `json:"appRole,omitempty"`
// +optional
Kubernetes *VaultKubernetesAuth `json:"kubernetes,omitempty"`
}
func (*VaultAuth) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VaultAuth.
func (*VaultAuth) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VaultCASetting ¶
type VaultCASetting struct {
Auth VaultAuth `json:"auth"`
Server string `json:"server"`
Path string `json:"path"`
Namespace string `json:"namespace,omitempty"`
CABundle []byte `json:"caBundle,omitempty"`
}
func (*VaultCASetting) DeepCopy ¶
func (in *VaultCASetting) DeepCopy() *VaultCASetting
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VaultCASetting.
func (*VaultCASetting) DeepCopyInto ¶
func (in *VaultCASetting) DeepCopyInto(out *VaultCASetting)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VaultConfiguration ¶
type VaultConfiguration struct {
Host string `json:"host"`
Port int `json:"port"`
Name string `json:"name"`
EngineType string `json:"engineType"`
}
func (*VaultConfiguration) DeepCopy ¶
func (in *VaultConfiguration) DeepCopy() *VaultConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VaultConfiguration.
func (*VaultConfiguration) DeepCopyInto ¶
func (in *VaultConfiguration) DeepCopyInto(out *VaultConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VaultKubernetesAuth ¶
type VaultKubernetesAuth struct {
// +optional
Path string `json:"mountPath,omitempty"`
SecretRef meta.SecretKeySelector `json:"secretRef"`
Role string `json:"role"`
}
func (*VaultKubernetesAuth) DeepCopy ¶
func (in *VaultKubernetesAuth) DeepCopy() *VaultKubernetesAuth
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VaultKubernetesAuth.
func (*VaultKubernetesAuth) DeepCopyInto ¶
func (in *VaultKubernetesAuth) DeepCopyInto(out *VaultKubernetesAuth)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type X509Subject ¶
type X509Subject struct {
// +optional
Organizations []string `json:"organizations,omitempty"`
// +optional
Countries []string `json:"countries,omitempty"`
// +optional
OrganizationalUnits []string `json:"organizationalUnits,omitempty"`
// +optional
Localities []string `json:"localities,omitempty"`
// +optional
Provinces []string `json:"provinces,omitempty"`
// +optional
StreetAddresses []string `json:"streetAddresses,omitempty"`
// +optional
PostalCodes []string `json:"postalCodes,omitempty"`
// +optional
SerialNumber string `json:"serialNumber,omitempty"`
}
func (*X509Subject) DeepCopy ¶
func (in *X509Subject) DeepCopy() *X509Subject
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new X509Subject.
func (*X509Subject) DeepCopyInto ¶
func (in *X509Subject) DeepCopyInto(out *X509Subject)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.